<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @package    Post_TIMELINE
 * @subpackage Post_TIMELINE/public
 * @author     agilelogix <support@agilelogix.com>
 */
class Post_TIMELINE_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    0.0.1
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    0.0.1
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    0.0.1
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		$this->defaults = array(
							"ptl-fav-icon" => "fa-heart",
							"ptl-post-icon" => "1",
							"ptl-sort" => "1",
							"ptl-post-type" => "post-timeline",
							"ptl-date-format" => "M j, Y",
							"ptl-post-length" => "350",
							"ptl-fonts" => array(array("family" => "")),
							"ptl-bg-color" => "#ffffff",
							"ptl-post-bg-color" => "",
							"ptl-post-head-color" => "#FFFFFF",
							"ptl-post-desc-color" => "#FFFFFF",
							"ptl-post-bg" => "off",
							"ptl-nav-color" => "#4285F4",
							"ptl-nav-type" => "style-2",
							/**/
							"ptl-nav-status" => "on",
							"ptl-rm-status" => "on"
							);
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    0.0.1
	 */
	public function enqueue_styles() {

		wp_enqueue_style( $this->plugin_name.'-reset', POST_TIMELINE_URL_PATH . 'public/css/post-timeline.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name.'-bootstrap', POST_TIMELINE_URL_PATH . 'public/css/bootstrap.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name.'-bootstrap-theme', POST_TIMELINE_URL_PATH . 'public/css/bootstrap-theme.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name.'-fontawsom', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.css', array(), $this->version, 'all' );
	}

	public function enqueue_scripts() {

		$cache  = false;
		$bottom = true;

		wp_enqueue_script( $this->plugin_name.'-libs', POST_TIMELINE_URL_PATH . 'public/js/libs_new.js', array('jquery'), $this->version, $bottom );
		wp_enqueue_script( $this->plugin_name.'-timeline', POST_TIMELINE_URL_PATH . 'public/js/post-timeline.js', array('jquery'), $this->version, $bottom );

		wp_localize_script( $this->plugin_name.'-timeline', 'PTL_REMOTE', array(
		    'ajax_url' => admin_url( 'admin-ajax.php' )
		));
	}

	/**
	 * Register individual shortcode [post_timeline]
	 *
	 * @since    0.0.1
	 */
  	public function add_shortcodes() {
  		

  		add_shortcode( 'post-timeline', array( $this, 'timeline_shortcode' ) );
  	}

	/**
	 * Callback function for individual timeline shortcode [post-timeline]
	 *
	 * @since    0.0.1
	 */
  	public function timeline_shortcode( $atts ) {

  		//call the helper
  		require_once POST_TIMELINE_PLUGIN_PATH.'includes/helper.php';
  		
		$template 		= '1';
		$this->template = 'post-timeline-public-1.php';
		$this->temp_id  = $template;
		
		//1,11,10,12
  		wp_enqueue_style( $this->plugin_name.'-timeline', POST_TIMELINE_URL_PATH . 'public/css/post-timeline-public-'.$template.'.css', array(), $this->version, 'all' );


  		//If empty
  		if(!$atts) {

  			$atts = array();
  		}
		
		$paged = 1;

		//Extend with defaults
		$ptl_settings = $this->defaults;

		$ptl_settings = shortcode_atts( $ptl_settings, $atts );

		//add the missing attributes into settings
		$ptl_settings = array_merge($ptl_settings,$atts);

		//Restrict category
		$category_id = isset($atts['category_id'])?$atts['category_id']:null;

		$per_page = -1;

		$query_args = array (
			'post_type' 	 => $ptl_settings['ptl-post-type'],
			'post_status' 	 => 'publish',
			'posts_per_page' => $per_page,
			'meta_key'  => 'ptl-post-date',
			'orderby'   => 'meta_value',
			'order' 	=> 'ASC'
		);


		//Get the title Post
		$top_post = (isset($atts['header']) && $atts['header'])?get_post($atts['header']):null;

		//remove header post
		if($top_post) {

			$query_args['post__not_in'] = array($top_post->ID);
			$ptl_settings['top_id'] 	= $top_post->ID;
		}

		//Filter by Category
		if($category_id)  {
			
			$query_args['cat'] =  $category_id; //verified
		}

		
		//Sort by Tag if On Tags
		$ptl_settings['by_date'] = (isset($ptl_settings['by_date']) && $ptl_settings['by_date'] === '0')?false:true;

		
		$the_query = new WP_Query( $query_args );
		$posts 	   = $the_query->posts;	

  		
		$pagination = null;


		//reset it
		wp_reset_postdata();

		//ID is valid, show timeline.
		return $this->output_timeline( array('ptl_posts'=> $posts, 'paginate' => $pagination, 'top_post' => $top_post),$ptl_settings );
  	}


  	private function get_the_url() {

		return ( is_ssl() ? 'https://' : 'http://' ) . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
	}

	/*Insert the Post*/
	function Generate_Featured_Image( $image_url, $post_id  ){
	    
	    $upload_dir = wp_upload_dir();
	    $image_data = file_get_contents($image_url);
	    $filename = basename($image_url);
	    if(wp_mkdir_p($upload_dir['path']))     $file = $upload_dir['path'] . '/' . $filename;
	    else                                    $file = $upload_dir['basedir'] . '/' . $filename;
	    file_put_contents($file, $image_data);

	    $wp_filetype = wp_check_filetype($filename, null );
	    $attachment = array(
	        'post_mime_type' => $wp_filetype['type'],
	        'post_title' => sanitize_file_name($filename),
	        'post_content' => '',
	        'post_status' => 'inherit'
	    );
	    $attach_id = wp_insert_attachment( $attachment, $file, $post_id );
	    require_once(ABSPATH . 'wp-admin/includes/image.php');
	    $attach_data = wp_generate_attachment_metadata( $attach_id, $file );
	    $res1= wp_update_attachment_metadata( $attach_id, $attach_data );
	    $res2= set_post_thumbnail( $post_id, $attach_id );
	}

	private function rand_date() {

		$datestart = strtotime('2005-12-10');//you can change it to your timestamp;
		$dateend = strtotime('2015-12-31');//you can change it to your timestamp;

		$daystep = 86400;

		$datebetween = abs(($dateend - $datestart) / $daystep);

		$randomday = rand(0, $datebetween);


		return date("Y-m-d", $datestart + ($randomday * $daystep));
	}


	private function add_posts_test() {


		$years 		  = array(2000,2001,2003,2005,2007,2009,2010,2011,2012,2013,2015,2016,2017);
		$colors_codes = array("#6dff80","#86ffef","#FF7473","#0199A0","#c59cf1","#fba9ec","#8eefac","#43bff1","#ffbd38");

		for($i = 21; $i < 40; $i++) {

			// Gather post data.
			$my_post = array(
			    'post_title'    => 'A Custom Post '.$i,
			    'post_content'  => "It is a long established {$i} fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of using Lorem Ipsum is that it has a more-or-less normal distribution of letters, as opposed to using 'Content here, content here', making it look like readable English. Many desktop publishing packages and web page editors now use Lorem Ipsum as their default model text, and a search for 'lorem ipsum' will uncover many web sites still in their infancy. Various versions have evolved over the years, sometimes by accident, sometimes on purpose (injected humour and the like).",
			    'post_type'     => 'post-timeline',
			    'post_status'   => 'publish',
			    'post_author'   => 1,
			    'post_category' => array( 6 )
			);
			 

			$year = $years[rand(0,12)];

			// Insert the post into the database.
			$postId = wp_insert_post( $my_post );

			add_post_meta( $postId, 'ptl-post-tag', rand(3,5), true );
			add_post_meta( $postId, 'ptl-post-color', $colors_codes[rand(0,8)], true );
			add_post_meta( $postId, 'ptl-img-txt-pos', '0', true );
			add_post_meta( $postId, 'ptl-post-type', '0', true );
			add_post_meta( $postId, 'ptl-post-date', $this->rand_date(), true );
			add_post_meta( $postId, 'ptl-post-order', '1', true );
			add_post_meta( $postId, 'ptl-fav-icon', 'fa fa-heart', true );
			
			//Insert the Meta and Attachment
			$this->Generate_Featured_Image("http://design.localhost.com/image2.jpg",$postId);
		}
	}

	/**
	 * Output a timeline
	 *
	 * @since    0.0.1
	 */
	public function output_timeline( $ptl_response,$all_configs ) {

		
		//$this->add_posts_test();die('g');

		$prev_index  = ( isset($_GET['last']) ) ? $_GET['last'] : null;
		$ptl_admin   = false;

		

		//get the parent
		$parent_post = null;

		if($ptl_response['top_post']) {
			
			$parent_post = $ptl_response['top_post'];
			$parent_post->custom = get_post_custom($parent_post->ID);
		}
		
		/*
		$timeline_posts 	 = get_children( $args );
		*/

		$timeline_posts = $ptl_response['ptl_posts'];


		//All the configs showing here
		$all_configs['template'] = $this->temp_id;

		$template_wrapper = '';
		

		//apply format
		$format = $all_configs['ptl-date-format'];


		foreach($timeline_posts as $child) {

			$child->custom 		= get_post_custom($child->ID);

			//set icon
			if(true || $all_configs['ptl-post-icon'] == '1') {

				$child->icon = isset($child->custom['ptl-fav-icon'][0])?('fa '.$child->custom['ptl-fav-icon'][0]):$all_configs['ptl-fav-icon'];
			} 
			else
				$child->icon = '';	
			

			$date  = isset($child->custom['ptl-post-date'][0])?$child->custom['ptl-post-date'][0]:$child->post_date;
				
			//Set Text Position
			if(!isset($child->custom['ptl-img-txt-pos'][0]))
				$child->custom['ptl-img-txt-pos'] = array(0);


			if(!isset($child->custom['ptl-tag-line'][0]))
				$child->custom['ptl-tag-line'] = array(null);

			

			//Add the Tag
			if(!isset($child->custom['ptl-post-tag'][0]))
				$child->custom['ptl-post-tag'] = array(0);
			
			$child->tag_id = $child->custom['ptl-post-tag'][0];

			
			//$date = null;
			if(!$date) {

				$date = $child->post_date;
			}

			$child->event_date  = $date;
			
			if($date) {

				$child->date_str = date_i18n($format,strtotime($child->custom['ptl-post-date'][0]));
			}
			else
				$child->date_str = '';
		}

	
		foreach($timeline_posts as &$p) {
			$p = (object)$p;
		}


		//the range of dates
		$date_range = array('','');
		$tag_list   = array();


		$ptl_response['by_date'] = $all_configs['by_date'];
		$by_date = $ptl_response['by_date'];


		if($ptl_response['by_date']) {

			//Sort By Year :: disable sorting by date
			usort($timeline_posts, array($this, "cmp_year"));

			//DATE RANGE
			if(isset($timeline_posts[0]) && $timeline_posts[0]->event_date) {

				$_comp = explode('-', $timeline_posts[0]->event_date);
				$date_range[0] = $_comp[0];
			}

			$last_post = ($timeline_posts)?$timeline_posts[count($timeline_posts) - 1]:null;
			if(isset($last_post) && $last_post->event_date) {

				$_comp = explode('-', $last_post->event_date);
				$date_range[1] = $_comp[0];
			}	

			//parent post
			if($parent_post && !empty($date_range)) {

				$parent_post->time_range = $date_range[0].' - '.$date_range[1];
			}

			//GET Year
			$tag_list = $this->get_year_list($timeline_posts);
		}
		//by Tag
		else {

			//GET TAGS
			$tag_list = $this->get_tag_list($timeline_posts);

		}

		//Set the variables used
		$color_nav 	  = $all_configs['ptl-nav-color'];
		$ptl_URL 	  = site_url()."/".$all_configs['ptl-post-type']."/";
		$tmpl_class   = 'ptl-tmpl-'.$this->temp_id;
		$color_nav    = $all_configs['ptl-nav-color'];
		$bg_color     = $all_configs['ptl-bg-color'];
		$nav_class    = $all_configs['ptl-nav-type'];
		$head_color   = $all_configs['ptl-post-head-color'];
		$desc_color   = $all_configs['ptl-post-desc-color'];
		$post_bg      = $all_configs['ptl-post-bg-color'];
		


		//ptl-anim-type,ptl-css
		$all_configs['ptl-nav-status']  = (isset($all_configs['ptl-nav-status']) && $all_configs['ptl-nav-status'] == 'off')?false:true;
		$all_configs['ptl-rm-status']   = (isset($all_configs['ptl-rm-status']) && $all_configs['ptl-rm-status'] == 'off')?false:true;
		$all_configs['ptl-post-length'] = intval($all_configs['ptl-post-length']);

		if($all_configs['ptl-post-length'] <= 0 || $all_configs['ptl-post-length'] > 1000)
			$all_configs['ptl-post-length'] = 350; 
		
		//single side class
		if(!isset($all_configs['class'])) {

			$all_configs['class'] = '';
		}

		/*hack change var*/
		$child_posts = $timeline_posts;
		$uniqid 	 = uniqid();
		

		$template_file = $this->template;


		//Template File

		if($template_file) {

			if ( $theme_file   = locate_template( array ( $template_file ) ) ) {
	            $template_file = $theme_file;
	        }
	        else {
	            $template_file = plugin_dir_path( __FILE__ ) . 'partials/' . $template_file;
	        }
		}

		
		ob_start();

		include( plugin_dir_path( __FILE__ ) . '/partials/post-timeline-wrapper'.$template_wrapper.'.php' );
		
		$output = ob_get_contents();
		ob_end_clean();

		wp_localize_script( $this->plugin_name.'-timeline', ('ptl_config_'.$uniqid), $all_configs);
		
		return $output;
	}


	private function get_year_list($timeline_posts) {


		$tag_list = array();
		foreach($timeline_posts as $child) {

			$date = $child->event_date;
			
			if($date) {
				$date_comp = explode('-', $date);
				$child->date_comp = $date_comp;

				//capture the year
				if(count($date_comp) >= 1) {
						
					if(!in_array($date_comp[0], $tag_list))
					$tag_list[] = $date_comp[0];
				}
			}
		}

		//make it key value pair
		$temp_list = array();

		foreach($tag_list as $y) {
			
			$temp_list[$y] = $y;
		}

		return $temp_list;
		
	}

	private function get_tag_list($timeline_posts) {


		$tag_list = array();
		foreach($timeline_posts as $child) {

			$tag = $child->custom['ptl-post-tag'];
				
			// Missing Tags
			if(!$tag[0]) {

				$child->custom['ptl-post-tag'] = $tag = array(0);
			}

			if($tag) {
				
				$child->date_comp = $tag;

				//capture the Tag
				if(!in_array($tag[0], $tag_list))
					$tag_list[] = $tag[0];
			}
		}

		//make it key value pair
		$temp_list = array();

		foreach($tag_list as $l) {
			
			$term = null;

			//Empty Terms
			if($l == 0) {

				$term = new \stdclass();
				$term->term_id = 0;
				$term->name    = 'None';
			}
			else {

				$term = get_term($l);

				//Term not found
				if(!$term) {

					$term = new \stdclass();
					$term->term_id = 0;
					$term->name    = 'None';
				}
			}

			if($term) {

				$temp_list[$term->term_id] = $term->name;				
			}
		}

		return $temp_list;
		
	}


	private function cmp_year($a, $b){
    	
    	return strcmp($a->event_date, $b->event_date);
	}

	private function cmp_tag($a, $b){
    	
    	return strcmp($a->tag_id, $b->tag_id);
	}

  	/**
	 * Include in loop so they can be displayed among regular posts.
	 *
	 * @since    0.0.1
	 */
	function add_timelines_to_loop( $query ) {

		global $pagenow;

		if( $pagenow == 'edit.php' ) {
			
			return;
		}

		// Querying specific page (not set as home/posts page) or attachment
		if( !$query->is_home() ) {
			
			if( $query->is_page() || $query->is_attachment() ) {
				return;
			}
		}

		// Querying a specific taxonomy
		if( !is_null( $query->tax_query ) ) {
			
			$tax_queries = $query->tax_query->queries;
			$timeline_taxonomies = get_object_taxonomies( 'post-timeline' );

			if( is_array($tax_queries) ) {
			
				foreach( $tax_queries as $tax_query ) {
			
					  	if( isset( $tax_query['taxonomy'] ) && $tax_query['taxonomy'] !== '' && !in_array( $tax_query['taxonomy'], $timeline_taxonomies ) ) {
				
						  	return;
					  	}
					}
				}
			}

		$post_type = $query->get( 'post_type' );

		if( $post_type == '' || $post_type == 'post' ) {
			$post_type = array( 'post','post-timeline' );
		}
		else if( is_array($post_type) ) {
			
			if( in_array('post', $post_type) && !in_array('post-timeline', $post_type) ) {
				
				$post_type[] = 'post-timeline';
			}
		}

		$post_type = apply_filters( 'post_timeline_query_posts', $post_type, $query );

		$query->set( 'post_type', $post_type );

		return;

	}

}
